# -*- coding:utf-8 -*-
import matplotlib.pyplot as plt
from matplotlib import cm
import numpy as np

# ============================================================================
# 各種プロットを作成するクラス
# ============================================================================
class MakePlot:
    '''プロットを作成．'''

    #-----------------------------------------------------------------
    # コンストラクター
    #-----------------------------------------------------------------
    def __init__(self):
        ''' コンストラクター '''
        pass
        
    #-----------------------------------------------------------------
    # ラインプロット
    #-----------------------------------------------------------------
    def line(self, x, y, para, output):
        ''' ラインプロットを作成 '''
        plot = plt.figure(figsize=(8 ,6),dpi=100)
        ax1 = plot.add_subplot(1,1,1)
        ax1.set_xlabel(para['x']['title'], fontsize=20)
        ax1.set_ylabel(para['y']['title'], fontsize=20)
        ax1.tick_params(labelsize=14)
        ax1.tick_params(axis='both', length=16, which='major', direction='in',
                        bottom=True, top=True, left=True, right=True)
        ax1.tick_params(axis='both', length=8,  which='minor', direction='in',
                        bottom=True, top=True, left=True, right=True)
        ax1.set_xticks(np.arange(para['x']['range'][0],
                                 para['x']['range'][1]+para['x']['tick_step'],
                                 para['x']['tick_step']))
        ax1.set_yticks(np.arange(para['y']['range'][0],
                                 para['y']['range'][1]+para['y']['tick_step'],
                                 para['y']['tick_step']))
        ax1.grid(b=True, which='major', color='#666666', linestyle='-')
        ax1.grid(b=True, which='minor', color='#999999', linestyle='-', alpha=0.5)
        ax1.set_xlim(para['x']['range'])
        ax1.set_ylim(para['y']['range'])
        ax1.minorticks_on()
        ax1.plot(x, y, 'r-')
        
        # ----- スクリーン表示 -----
        plot.tight_layout()
        plt.pause(2)
        
        # ----- 画像ファイル作成 -----
        plot.savefig('{0:s}'.format(output+'.svg'),
                     orientation='portrait', transparent=False, bbox_inches='tight')
        plt.cla()
        plot.clf()


    #-----------------------------------------------------------------
    # 23D ラインプロット
    #-----------------------------------------------------------------
    def line_3D(self, x, y, z, para, output):
        ''' 3D ラインプロットの作成 '''
        plot = plt.figure(figsize=(8 ,6),dpi=100)
        ax1 = plot.add_subplot(1, 1, 1, projection='3d')
        ax1.set_xlabel(para['x']['title'], fontsize=12, fontname='serif')
        ax1.set_ylabel(para['y']['title'], fontsize=12, fontname='serif')
        ax1.set_zlabel(para['z']['title'], fontsize=12, fontname='serif')
        ax1.tick_params(axis='both', length=10,  which='major', direction='in')
        ax1.set_xticks(np.arange(para['x']['range'][0],
                                 para['x']['range'][1]+para['x']['tick_step'],
                                 para['x']['tick_step']))
        ax1.set_yticks(np.arange(para['y']['range'][0],
                                 para['y']['range'][1]+para['y']['tick_step'],
                                 para['y']['tick_step']))
        ax1.set_zticks(np.arange(para['z']['range'][0],
                                 para['z']['range'][1]+para['z']['tick_step'],
                                 para['z']['tick_step']))
        ax1.set_xlim(para['x']['range'])
        ax1.set_ylim(para['y']['range'])
        ax1.set_zlim(para['z']['range'])
        ax1.plot_surface(x, y, z, rstride=1, cstride=1, cmap=cm.coolwarm, \
                         linewidth=0.5, edgecolors='black')

        # ----- スクリーン表示 -----
        plot.tight_layout()
        plt.pause(2)
        
        # ----- 画像ファイル作成 -----
        plot.savefig('{0:s}'.format(output+'.svg'),
                     orientation='portrait', transparent=False, bbox_inches='tight')
        plt.cla()
        plot.clf()
